#!/bin/bash

# Enter the environment variables necessary for CLI tool to function:
export JAVA_HOME=
export AWS_CREDENTIAL_FILE=
export AWS_CLOUDWATCH_HOME=
export PATH=$PATH:$AWS_CLOUDWATCH_HOME/bin
export AWS_CLOUDWATCH_URL=https://mon-api.jp-e1.cloudn-service.com/

# Define the namespace and dimension name-value pair for the resource you will be creating custom metrics for:
NAMESPACE="namespace"
DIMENSIONS="dimensionname=dimensionvalue"

# Calculate memory usage
MEMTOTAL=`free -m | grep 'Mem' | tr -s ' ' | cut -d ' ' -f 2`
MEMUSED=`free -m | grep 'buffers/cache' | tr -s ' ' | cut -d ' ' -f 3`
MEMUSAGE=`echo "${MEMUSED} / ${MEMTOTAL} * 100" | bc -l`
echo "${MEMUSAGE}"

# Calculate swap usage
SWAPTOTAL=`free -m | grep 'Swap' | tr -s ' ' | cut -d ' ' -f 2`
SWAPUSED=`free -m | grep 'Swap' | tr -s ' ' | cut -d ' ' -f 3`
SWAPUSAGE=`echo "${SWAPUSED} / ${SWAPTOTAL} * 100" | bc -l`
echo "${SWAPUSAGE}"

# Get load average data of the last minute, the last 5 minutes, and the last 15 minutes, respectively.
LOADAVG1=`uptime | tr -s ' ' | cut -d ' ' -f 9 | cut -d ',' -f 1`
#LOADAVG5=`uptime | tr -s ' ' | cut -d ' ' -f 10 | cut -d ',' -f 1`
#LOADAVG15=`uptime | tr -s ' ' | cut -d ' ' -f 11`

# Pass the memory usage, swap usage, and load average data to the "value" parameter of the PutMetricData API and execute
mon-put-data --metric-name "MemoryUsage" --namespace "${NAMESPACE}" --dimensions "${DIMENSIONS}" --value "${MEMUSAGE}" --unit "Percent"

mon-put-data --metric-name "SwapUsage" --namespace "${NAMESPACE}" --dimensions "${DIMENSIONS}" --value "${SWAPUSAGE}" --unit "Percent"

mon-put-data --metric-name "LoadAveragePercentageFromPastMinute" --namespace "${NAMESPACE}" --dimensions "${DIMENSIONS}" --value "${LOADAVG1}" --unit "Percent"
#mon-put-data --metric-name "LoadAveragePercentageFromPast5Minutes" --namespace "${NAMESPACE}" --dimensions "${DIMENSIONS}" --value "${LOADAVG5}" --unit "Percent"
#mon-put-data --metric-name "LoadAveragePercentageFromPast15Minutes" --namespace "${NAMESPACE}" --dimensions "${DIMENSIONS}" --value "${LOADAVG15}" --unit "Percent"